/*
 * ONF website ZMI extensions
 */

/* globals L, PyAMS_GIS */

(function($, globals) {

	'use strict';

	var MyAMS = globals.MyAMS;

	var ONF_website = {

		/**
		 * TinyMCE editor configuration
		 */
		TinyMCE: {

			initEditor: function (settings) {
				settings = PyAMS_content.TinyMCE.initEditor.call(this, settings);
				settings.menubar = 'file edit insert view table tools help';
				if (settings.toolbar1) {
					settings.toolbar1 = "undo redo | pastetext | header-h3 header-h4 | bold italic superscript | " +
										"alignleft aligncenter alignright alignjustify | bullist numlist outdent indent";
				}
				return settings;
			}
		},


		/**
		 * Location management
		 */

		location: {

			/* Move location map marker to given position on filter selection */
			moveMapMarkerTo: function(event, options) {
				if (event.added) {
					var source = $(this);
					var map = source.parents('.map-header')
									.siblings('.map');
					var fieldname = map.data('map-leaflet-fieldname');
					var projection = $('select[name="' + fieldname + '.widgets.projection:list"]');
					MyAMS.jsonrpc.post('getLocationCoords', {
											source: event.added,
											to_srid: projection.val()
									   }, {
											url: '/api/onf_website/json'
									   }, function(data) {
											var result = data.result;
											PyAMS_GIS.position.moveMarkerTo(map, result.position, result.srid);
											var leafmap = map.data('leafmap');
											var layer = map.data('json-layer');
											if (layer !== undefined) {
												layer.remove();
											}
											var style = {
												color: '#dd0000',
												weight: 3,
												opacity: 0.7
											};
											style = $.extend({}, style, result.style);
											layer = L.geoJSON(result.geometry, {
												style: style
											});
											layer.addTo(leafmap);
											map.data('json-layer', layer);
											leafmap.fitBounds(layer.getBounds());
									   });
				}
			}
		}
	};


	/**
	 * Location map listener to 'marker.changed' event
	 * If marker position is overriding a forest, get forest geometry and display it
	 * as GeoJSON, and update filter area with selected forest name
	 */
	$(document).on('marker.changed', function(event, map, position) {
		map = $(map);
		var mapdata = map.data();
		var fieldname = mapdata.mapLeafletFieldname;
		var srid = $('select[name="' + fieldname + '.widgets.projection:list"]');
		MyAMS.jsonrpc.post('getForestAt', {
			position: position,
			srid: srid.val()
		}, {
			url: '/api/onf_website/json'
		}, function(data) {
			// Reset map layer
			var leafmap = mapdata.leafmap;
			var layer = mapdata.jsonLayer;
			if (layer !== undefined) {
				layer.remove();
			}
			var filter = $('input[name="pyams_gis.map.header_location"]');
			var result = data.result;
			if (result) {
				// Update location filter
				filter.select2('data', result);
				// Update map with selected geometry
				layer = L.geoJSON(result.geometry, {
					style: {
						color: '#00dd00',
						weight: 3,
						opacity: 0.7
					}
				});
				layer.addTo(leafmap);
				map.data('json-layer', layer);
			} else {
				filter.select2('data', null);
			}
		});
	});


	/**
	 * Location map listener to 'marker.closed.position' event
	 * If marker selection dialog is closed with 'OK' button, if filter is not empty
	 * and if there is no already selected forest, update forests selection area with
	 * filter data
	 */
	$(document).on('marker.closed.position', function(event, options) {
		var filter = $('input[name="pyams_gis.map.header_location"]');
		if (filter.val()) {
			var forests = $('input[name="form.widgets.forests"]');
			if (forests && !forests.val()) {
				forests.select2('data', filter.select2('data'));
			}
		}
	});

	/**
	 * Location map listener to 'marker.cleare.*' event
	 * Reset filter on position or area reset
	 */
	$(document).on('marker.cleared.position marker.cleared.area', function(event) {
		var filter = $('input[name="pyams_gis.map.header_location"]');
		filter.select2('data', null);
	});

	globals.ONF_website = ONF_website;

})(jQuery, this);
